"""Add Requires-Python column to Python metadata

Revision ID: d808ef831749
Revises: 54d50b0eeb33
Create Date: 2019-10-22 10:30:43.326485+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'd808ef831749'
down_revision = '54d50b0eeb33'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('python_package_metadata', sa.Column('requires_python', sa.String(length=256), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('python_package_metadata', 'requires_python')
    # ### end Alembic commands ###
