"""Index platform

Revision ID: 7c261487d4d4
Revises: 9542eba46906
Create Date: 2020-06-08 07:41:56.496722+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '7c261487d4d4'
down_revision = '9542eba46906'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('depends_on_platform', 'depends_on', ['platform'], unique=False)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('depends_on_platform', table_name='depends_on')
    # ### end Alembic commands ###
